==> ejc-proequipmentp-impl-3.0.0-20220706.082601-159-sources.jar: com/ejianc/business/asset/bean/AssetEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 *  固定资产
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_asset")
public class AssetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 材料分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 材料分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 材料分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 材料id
    @TableField(value="equipment_code")
    private String equipmentCode; // 材料编码
    @TableField(value="equipment_name")
    private String equipmentName; // 材料名称
    @TableField(value="finance_push_flag")
    private Integer financePushFlag; // 是否推送财务1推送0不推送
    @TableField(value="finance_push_state")
    private Integer financePushState; // 财务推送状态1已推送0未推送
    @TableField(value="finance_type_id")
    private String financeTypeId; // 财务资产分类id
    @TableField(value="finance_asset_id")
    private String financeAssetId; // 财务资产id
    @TableField(value="finance_asset_code")
    private String financeAssetCode; // 财务资产编码
    @TableField(value="equipment_status")
    private Integer equipmentStatus; // 设备状态 1:再用 2:处置
    @TableField(value="asset_type")
    private Integer assetType; // 资产类型 1:固定资产 2:普通资产
    @TableField(value="check_date")
    private Date checkDate; // 验收日期
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属项目部Id
    @TableField(value="org_name")
    private String orgName; // 所属项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="source_type")
    private Integer sourceType; // 来源 1：验收 2：期初 3：调拨
    @TableField(value="amortize_type")
    private String amortizeType; // 摊销方式
    @TableField(value="property_right_company_id")
    private Long propertyRightCompanyId; // 产权单位id
    @TableField(value="property_right_company")
    private String propertyRightCompany; // 产权单位
    @TableField(value="manage_company")
    private String manageCompany; // 管理单位
    @TableField(value="manage_company_id")
    private Long manageCompanyId; // 管理单位id
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_amortize_mny")
    private BigDecimal lastAmortizeMny; // 累计摊销金额(无税)
    @TableField(value="last_amortize_tax_mny")
    private BigDecimal lastAmortizeTaxMny; // 累计摊销金额(含税)
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额(无税)
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额(含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="certificate_num")
    private String certificateNum; // 合格证号
    @TableField(value="production_date")
    private Date productionDate; // 生产日期
    @TableField(value="leave_factory_code")
    private String leaveFactoryCode; // 出厂编号
    @TableField(value="random_tool")
    private String randomTool; // 随机工具
    @TableField(value="ability")
    private String ability; // 能力
    @TableField(value="weight")
    private BigDecimal weight; // 重量（t）
    @TableField(value="power")
    private BigDecimal power; // 动力（kw）
    @TableField(value="own_weight")
    private BigDecimal ownWeight; // 自重（t）
    @TableField(value="appearance_size")
    private BigDecimal appearanceSize; // 外形尺寸（毫米）
    @TableField(value="model_explain")
    private String modelExplain; // 型号说明
    @TableField(value="supplier_name")
    private String supplierName; // 供应商
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商id
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 出厂日期

    @TableField(value="residual_value_rate")
    private BigDecimal residualValueRate; // 残值率
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率

    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Integer getFinancePushFlag() {
        return financePushFlag;
    }

    public void setFinancePushFlag(Integer financePushFlag) {
        this.financePushFlag = financePushFlag;
    }
    public Integer getFinancePushState() {
        return financePushState;
    }

    public void setFinancePushState(Integer financePushState) {
        this.financePushState = financePushState;
    }
    public String getFinanceTypeId() {
        return financeTypeId;
    }

    public void setFinanceTypeId(String financeTypeId) {
        this.financeTypeId = financeTypeId;
    }
    public String getFinanceAssetId() {
        return financeAssetId;
    }

    public void setFinanceAssetId(String financeAssetId) {
        this.financeAssetId = financeAssetId;
    }
    public String getFinanceAssetCode() {
        return financeAssetCode;
    }

    public void setFinanceAssetCode(String financeAssetCode) {
        this.financeAssetCode = financeAssetCode;
    }
    public Integer getEquipmentStatus() {
        return equipmentStatus;
    }

    public void setEquipmentStatus(Integer equipmentStatus) {
        this.equipmentStatus = equipmentStatus;
    }
    public Integer getAssetType() {
        return assetType;
    }

    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getAmortizeType() {
        return amortizeType;
    }

    public void setAmortizeType(String amortizeType) {
        this.amortizeType = amortizeType;
    }
    public Long getPropertyRightCompanyId() {
        return propertyRightCompanyId;
    }

    public void setPropertyRightCompanyId(Long propertyRightCompanyId) {
        this.propertyRightCompanyId = propertyRightCompanyId;
    }
    public String getPropertyRightCompany() {
        return propertyRightCompany;
    }

    public void setPropertyRightCompany(String propertyRightCompany) {
        this.propertyRightCompany = propertyRightCompany;
    }
    public String getManageCompany() {
        return manageCompany;
    }

    public void setManageCompany(String manageCompany) {
        this.manageCompany = manageCompany;
    }
    public Long getManageCompanyId() {
        return manageCompanyId;
    }

    public void setManageCompanyId(Long manageCompanyId) {
        this.manageCompanyId = manageCompanyId;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public BigDecimal getLastAmortizeMny() {
        return lastAmortizeMny;
    }

    public void setLastAmortizeMny(BigDecimal lastAmortizeMny) {
        this.lastAmortizeMny = lastAmortizeMny;
    }
    public BigDecimal getLastAmortizeTaxMny() {
        return lastAmortizeTaxMny;
    }

    public void setLastAmortizeTaxMny(BigDecimal lastAmortizeTaxMny) {
        this.lastAmortizeTaxMny = lastAmortizeTaxMny;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }
    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getCertificateNum() {
        return certificateNum;
    }

    public void setCertificateNum(String certificateNum) {
        this.certificateNum = certificateNum;
    }
    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }
    public String getLeaveFactoryCode() {
        return leaveFactoryCode;
    }

    public void setLeaveFactoryCode(String leaveFactoryCode) {
        this.leaveFactoryCode = leaveFactoryCode;
    }
    public String getRandomTool() {
        return randomTool;
    }

    public void setRandomTool(String randomTool) {
        this.randomTool = randomTool;
    }
    public String getAbility() {
        return ability;
    }

    public void setAbility(String ability) {
        this.ability = ability;
    }
    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }
    public BigDecimal getPower() {
        return power;
    }

    public void setPower(BigDecimal power) {
        this.power = power;
    }
    public BigDecimal getOwnWeight() {
        return ownWeight;
    }

    public void setOwnWeight(BigDecimal ownWeight) {
        this.ownWeight = ownWeight;
    }
    public BigDecimal getAppearanceSize() {
        return appearanceSize;
    }

    public void setAppearanceSize(BigDecimal appearanceSize) {
        this.appearanceSize = appearanceSize;
    }
    public String getModelExplain() {
        return modelExplain;
    }

    public void setModelExplain(String modelExplain) {
        this.modelExplain = modelExplain;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }

    public BigDecimal getResidualValueRate() {
        return residualValueRate;
    }

    public void setResidualValueRate(BigDecimal residualValueRate) {
        this.residualValueRate = residualValueRate;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

}

==> ejc-proequipmentp-impl-3.0.0-20220707.014603-162-sources.jar: com/ejianc/business/asset/bean/AssetEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 *  固定资产
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_asset")
public class AssetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 材料分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 材料分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 材料分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 材料id
    @TableField(value="equipment_code")
    private String equipmentCode; // 材料编码
    @TableField(value="equipment_name")
    private String equipmentName; // 材料名称
    @TableField(value="finance_push_flag")
    private Integer financePushFlag; // 是否推送财务1推送0不推送
    @TableField(value="finance_push_state")
    private Integer financePushState; // 财务推送状态1已推送0未推送
    @TableField(value="finance_type_id")
    private String financeTypeId; // 财务资产分类id
    @TableField(value="finance_asset_id")
    private String financeAssetId; // 财务资产id
    @TableField(value="finance_asset_code")
    private String financeAssetCode; // 财务资产编码
    @TableField(value="equipment_status")
    private Integer equipmentStatus; // 设备状态 1:再用 2:处置
    @TableField(value="asset_type")
    private Integer assetType; // 资产类型 1:固定资产 2:普通资产
    @TableField(value="check_date")
    private Date checkDate; // 验收日期
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属项目部Id
    @TableField(value="org_name")
    private String orgName; // 所属项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="source_type")
    private Integer sourceType; // 来源 1：验收 2：期初 3：调拨
    @TableField(value="amortize_type")
    private String amortizeType; // 摊销方式
    @TableField(value="property_right_company_id")
    private Long propertyRightCompanyId; // 产权单位id
    @TableField(value="property_right_company")
    private String propertyRightCompany; // 产权单位
    @TableField(value="manage_company")
    private String manageCompany; // 管理单位
    @TableField(value="manage_company_id")
    private Long manageCompanyId; // 管理单位id
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_amortize_mny")
    private BigDecimal lastAmortizeMny; // 累计摊销金额(无税)
    @TableField(value="last_amortize_tax_mny")
    private BigDecimal lastAmortizeTaxMny; // 累计摊销金额(含税)
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额(无税)
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额(含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="certificate_num")
    private String certificateNum; // 合格证号
    @TableField(value="production_date")
    private Date productionDate; // 生产日期
    @TableField(value="leave_factory_code")
    private String leaveFactoryCode; // 出厂编号
    @TableField(value="random_tool")
    private String randomTool; // 随机工具
    @TableField(value="ability")
    private String ability; // 能力
    @TableField(value="weight")
    private BigDecimal weight; // 重量（t）
    @TableField(value="power")
    private BigDecimal power; // 动力（kw）
    @TableField(value="own_weight")
    private BigDecimal ownWeight; // 自重（t）
    @TableField(value="appearance_size")
    private BigDecimal appearanceSize; // 外形尺寸（毫米）
    @TableField(value="model_explain")
    private String modelExplain; // 型号说明
    @TableField(value="supplier_name")
    private String supplierName; // 供应商
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商id
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 出厂日期
    @TableField(value="last_amortize_date")
    private Date lastAmortizeDate; // 上次摊销周期
    @TableField(value="residual_value_rate")
    private BigDecimal residualValueRate; // 残值率
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率

    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Integer getFinancePushFlag() {
        return financePushFlag;
    }

    public void setFinancePushFlag(Integer financePushFlag) {
        this.financePushFlag = financePushFlag;
    }
    public Integer getFinancePushState() {
        return financePushState;
    }

    public void setFinancePushState(Integer financePushState) {
        this.financePushState = financePushState;
    }
    public String getFinanceTypeId() {
        return financeTypeId;
    }

    public void setFinanceTypeId(String financeTypeId) {
        this.financeTypeId = financeTypeId;
    }
    public String getFinanceAssetId() {
        return financeAssetId;
    }

    public void setFinanceAssetId(String financeAssetId) {
        this.financeAssetId = financeAssetId;
    }
    public String getFinanceAssetCode() {
        return financeAssetCode;
    }

    public void setFinanceAssetCode(String financeAssetCode) {
        this.financeAssetCode = financeAssetCode;
    }
    public Integer getEquipmentStatus() {
        return equipmentStatus;
    }

    public void setEquipmentStatus(Integer equipmentStatus) {
        this.equipmentStatus = equipmentStatus;
    }
    public Integer getAssetType() {
        return assetType;
    }

    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getAmortizeType() {
        return amortizeType;
    }

    public void setAmortizeType(String amortizeType) {
        this.amortizeType = amortizeType;
    }
    public Long getPropertyRightCompanyId() {
        return propertyRightCompanyId;
    }

    public void setPropertyRightCompanyId(Long propertyRightCompanyId) {
        this.propertyRightCompanyId = propertyRightCompanyId;
    }
    public String getPropertyRightCompany() {
        return propertyRightCompany;
    }

    public void setPropertyRightCompany(String propertyRightCompany) {
        this.propertyRightCompany = propertyRightCompany;
    }
    public String getManageCompany() {
        return manageCompany;
    }

    public void setManageCompany(String manageCompany) {
        this.manageCompany = manageCompany;
    }
    public Long getManageCompanyId() {
        return manageCompanyId;
    }

    public void setManageCompanyId(Long manageCompanyId) {
        this.manageCompanyId = manageCompanyId;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public BigDecimal getLastAmortizeMny() {
        return lastAmortizeMny;
    }

    public void setLastAmortizeMny(BigDecimal lastAmortizeMny) {
        this.lastAmortizeMny = lastAmortizeMny;
    }
    public BigDecimal getLastAmortizeTaxMny() {
        return lastAmortizeTaxMny;
    }

    public void setLastAmortizeTaxMny(BigDecimal lastAmortizeTaxMny) {
        this.lastAmortizeTaxMny = lastAmortizeTaxMny;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }
    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getCertificateNum() {
        return certificateNum;
    }

    public void setCertificateNum(String certificateNum) {
        this.certificateNum = certificateNum;
    }
    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }
    public String getLeaveFactoryCode() {
        return leaveFactoryCode;
    }

    public void setLeaveFactoryCode(String leaveFactoryCode) {
        this.leaveFactoryCode = leaveFactoryCode;
    }
    public String getRandomTool() {
        return randomTool;
    }

    public void setRandomTool(String randomTool) {
        this.randomTool = randomTool;
    }
    public String getAbility() {
        return ability;
    }

    public void setAbility(String ability) {
        this.ability = ability;
    }
    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }
    public BigDecimal getPower() {
        return power;
    }

    public void setPower(BigDecimal power) {
        this.power = power;
    }
    public BigDecimal getOwnWeight() {
        return ownWeight;
    }

    public void setOwnWeight(BigDecimal ownWeight) {
        this.ownWeight = ownWeight;
    }
    public BigDecimal getAppearanceSize() {
        return appearanceSize;
    }

    public void setAppearanceSize(BigDecimal appearanceSize) {
        this.appearanceSize = appearanceSize;
    }
    public String getModelExplain() {
        return modelExplain;
    }

    public void setModelExplain(String modelExplain) {
        this.modelExplain = modelExplain;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }

    public BigDecimal getResidualValueRate() {
        return residualValueRate;
    }

    public void setResidualValueRate(BigDecimal residualValueRate) {
        this.residualValueRate = residualValueRate;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public Date getLastAmortizeDate() {
        return lastAmortizeDate;
    }

    public void setLastAmortizeDate(Date lastAmortizeDate) {
        this.lastAmortizeDate = lastAmortizeDate;
    }
}
